spike.version — spike 0.99.12-425 documentation

# Source code for spike.version

    # This file is generated automatically by dev_setup.py
    # Do not edit
    ProgramName = 'SPIKE'
    VersionName = 'Development version'
    version = '0.99.12'
    revision = '425'
    rev_date = '11-09-2019'

    def report():
        "prints version name when SPIKE starts"
        return '''
        ========================
              {0}
        ========================
        Version     : {1}
        Date        : {2}
        Revision Id : {3}
        ========================'''.format(ProgramName, version, rev_date, revision)
    print(report())